pub trait SSS:
Send
+ Sync
+ 'static { }Expand description
A marker which identifies a type as Send, Sync, and 'static.
This trait is automatically implemented for any types which fulfill these requirements,
and it is intended to be used as a shorthand for writing out each bound. For example:
use send_sync_static::SSS;
pub async fn send_data<D>(data: D) where D: SSS {
// Do something here
}Code written explicitly using Send, Sync, and 'static is fully interchangeable with this trait.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".